# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/pizi/recruit/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Pizi\\Recruit\\": "packages/pizi/recruit/src",
            "Pizi\\Recruit\\Seeders\\": "packages/pizi/recruit/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Pizi\Recruit\Providers\RecruitServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Recruit'  => Pizi\Recruit\Facades\Recruit::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Pizi\\Recruit\\Seeders\\RecruitTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Pizi\Recruit\Providers\RecruitServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Pizi\Recruit\Providers\RecruitServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Pizi\Recruit\Providers\RecruitServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/recruit/{modulename}

**User**

    http://path-to-route-folder/user/recruit/{modulename}

**Public**

    http://path-to-route-folder/recruits


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/recruit/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/recruit/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/recruit/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/recruit/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/recruit/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/recruit/{modulename}/{slug}
    METHOD: GET