<?php

namespace Pizi\Recruit\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Pizi\Recruit\Interfaces\JobRepositoryInterface;
use Pizi\Recruit\Repositories\Eloquent\Filters\JobPublicFilter;
use Pizi\Recruit\Repositories\Eloquent\Presenters\JobListPresenter;

class JobPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        JobRepositoryInterface $job
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('pizi.recruit.modules'), 'job', guard_url('job'));
        $this->repository = $job;
    }

    /**
     * Show job's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(JobPublicFilter::class)
            ->setPresenter(JobListPresenter::class)
            ->select('jobs.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('recruit::job.names'))
            ->view('recruit::public.job.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show job.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('recruit::job.name'))
            ->view('recruit::public.job.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
