<?php

namespace Pizi\Recruit\Providers;

use Illuminate\Support\ServiceProvider;
use Pizi\Recruit\Recruits;

class RecruitServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'recruit');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'recruit');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Pizi\Recruit\Providers\AuthServiceProvider::class);
        $this->app->register(\Pizi\Recruit\Providers\RouteServiceProvider::class);
        // $this->app->register(\Pizi\Recruit\Providers\EventServiceProvider::class);
        // $this->app->register(\Pizi\Recruit\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('pizi.recruit', function($app)
        {
            return $this->app->make(Recruits::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind Job to repository
        $this->app->bind(
            'Pizi\Recruit\Interfaces\JobRepositoryInterface',
            \Pizi\Recruit\Repositories\Eloquent\JobRepository::class
        );        // Bind Location to repository
        $this->app->bind(
            'Pizi\Recruit\Interfaces\LocationRepositoryInterface',
            \Pizi\Recruit\Repositories\Eloquent\LocationRepository::class
        );        // Bind JobApplication to repository
        $this->app->bind(
            'Pizi\Recruit\Interfaces\JobApplicationRepositoryInterface',
            \Pizi\Recruit\Repositories\Eloquent\JobApplicationRepository::class
        );
    }


    /**
     * Merges user's and recruit's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'pizi.recruit'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Pizi\Recruit\Commands\Recruit::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['pizi.recruit'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('pizi/recruit.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/recruit')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/recruit')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
