<?php

namespace Pizi\Recruit\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Pizi\Recruit\Models\Recruit;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Pizi\Recruit\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/recruit/job/*')) {
            Route::bind('job', function ($job) {
                $jobRepo = $this->app->make('Pizi\Recruit\Interfaces\JobRepositoryInterface');
                return $jobRepo->findorNew($job);
            });
        }
        if (Request::is('*/recruit/location/*')) {
            Route::bind('location', function ($location) {
                $locationRepo = $this->app->make('Pizi\Recruit\Interfaces\LocationRepositoryInterface');
                return $locationRepo->findorNew($location);
            });
        }
        if (Request::is('*/recruit/job_application/*')) {
            Route::bind('job_application', function ($job_application) {
                $job_applicationRepo = $this->app->make('Pizi\Recruit\Interfaces\JobApplicationRepositoryInterface');
                return $job_applicationRepo->findorNew($job_application);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
